==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let PointSeries = /*@__PURE__*/ (() => {
    class PointSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.ab = PointSeries.$;
        }
        get_c4() {
            return true;
        }
        bx() {
            return new PointSeriesView(this);
        }
        l2(a) {
            super.l2(a);
            this.vb = a;
        }
        gx() {
            return 0.7;
        }
        qb() {
            if (this.qa == 0) {
                return 2;
            }
            return super.qb();
        }
        ex(a, b) {
            let c = this.pq(this.pt(a), true, false);
            if (this.qk(a, b)) {
                return true;
            }
            return false;
        }
        l7(a, b, c, d) {
            super.l7(a, b, c, d);
        }
        get useHighMarkerFidelity() {
            return this.so;
        }
    }
    PointSeries.$t = /*@__PURE__*/ markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
})();
/**
 * @hidden
 */
export let PointSeriesView = /*@__PURE__*/ (() => {
    class PointSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.da = null;
            this.da = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.qh = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pf = a;
            this.e.gy = 3;
            this.e.gz = 2;
            this.e.g0 = 2;
            this.e.e9 = false;
        }
    }
    PointSeriesView.$t = /*@__PURE__*/ markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
})();

==> igniteui-react-charts-18.5.1.tgz: package/esm2015/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let PointSeries = /*@__PURE__*/ (() => {
    class PointSeries extends HorizontalAnchoredCategorySeries {
        bg() {
            return new PointSeries();
        }
        get_dy() {
            return true;
        }
        ch() {
            return new PointSeriesView(this);
        }
        o1(a) {
            super.o1(a);
            this.zf = a;
        }
        constructor() {
            super();
            this.ab = PointSeries.$;
        }
        ir() {
            return 0.7;
        }
        t5() {
            if (this.t4 == 0) {
                return 2;
            }
            return super.t5();
        }
        f5(a, b) {
            let c = this.ti(this.tn(a), true, false);
            if (this.ue(a, b)) {
                return true;
            }
            return false;
        }
        o9(a, b, c, d) {
            super.o9(a, b, c, d);
        }
        get useHighMarkerFidelity() {
            return this.wj;
        }
    }
    PointSeries.$t = /*@__PURE__*/ markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
})();
/**
 * @hidden
 */
export let PointSeriesView = /*@__PURE__*/ (() => {
    class PointSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.dd = null;
            this.dd = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.ub = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.s7 = a;
            this.e.is = 3;
            this.e.it = 2;
            this.e.iu = 2;
            this.e.gk = false;
        }
    }
    PointSeriesView.$t = /*@__PURE__*/ markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
})();
